import { AfterViewInit, ElementRef } from '@angular/core';
import * as i0 from "@angular/core";
declare type IconAlignType = 'left' | 'center' | 'right' | undefined;
declare type DividerType = 'full' | 'partial' | undefined;
/**
 * [InfoListItem Component](https://brightlayer-ui-components.github.io/angular/?path=/info/components-info-list-item--readme)
 *
 * The `<blui-info-list-item>` is intended to be used in List views.
 * It positions a title as well as optional subtitle(s), icon, and status stripe.
 */
export declare class InfoListItemComponent implements AfterViewInit {
    /** Show a colored background for the icon
     *
     * @default false
     * */
    avatar: boolean;
    /** Add a chevron icon on the right
     *
     * @default false
     * */
    chevron: boolean;
    /** Smaller height row with less padding
     *
     * @default false
     * */
    dense: boolean;
    /** Show a row separator below the row.  Can be `partial` | `full`
     *
     * `partial` - Divider does not expand full width of the ListItem
     *
     * `full`- Divider spans full width of the ListItem
     * */
    divider: DividerType;
    /** Disable the list item
     *
     * @default false
     * */
    disabled: boolean;
    /** Remove left padding if no icon is used */
    hidePadding: boolean;
    /** Icon alignment when avatar is set to false. Can be `left` | `right` | `center`
     *
     * `left` - Icon appears at the `flex-start` of the icon container.
     *
     * `right` - Icon appears at the `flex-end` of the icon container.
     *
     * `center` - Icon appears at the center of the icon container.
     *
     * @default left
     * */
    iconAlign: IconAlignType;
    /** Left border color */
    statusColor: string;
    /** When true, 3rd-line text overflow breaks onto the next line instead of using an ellipsis
     *
     * @default false
     * */
    wrapInfo: boolean;
    /** When true, 2nd-line text overflow breaks onto the next line instead of using an ellipsis
     *
     * @default false
     * */
    wrapSubtitle: boolean;
    /** When true, 1st-line text overflow breaks onto the next line instead of using an ellipsis
     *
     * @default false
     * */
    wrapTitle: boolean;
    titleEl: ElementRef;
    rightEl: ElementRef;
    isEmpty: (el: ElementRef) => boolean;
    ngAfterViewInit(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<InfoListItemComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<InfoListItemComponent, "blui-info-list-item", never, { "avatar": "avatar"; "chevron": "chevron"; "dense": "dense"; "divider": "divider"; "disabled": "disabled"; "hidePadding": "hidePadding"; "iconAlign": "iconAlign"; "statusColor": "statusColor"; "wrapInfo": "wrapInfo"; "wrapSubtitle": "wrapSubtitle"; "wrapTitle": "wrapTitle"; }, {}, never, ["[blui-icon]", "[blui-left-content]", "[blui-title]", "[blui-subtitle]", "[blui-info]", "[blui-right-content]"]>;
}
export {};
